@@ -1,6 +1,6 @@
 package BankAccount::Validator::UK;
 
-$BankAccount::Validator::UK::VERSION   = '0.24';
+$BankAccount::Validator::UK::VERSION   = '0.25';
 $BankAccount::Validator::UK::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ BankAccount::Validator::UK - Interface to validate UK bank account.
 
 =head1 VERSION
 
-Version 0.24
+Version 0.25
 
 =cut
 
@@ -36,7 +36,7 @@ has sort_code  => (is => 'ro', default => sub { return BankAccount::Validator::U
 The module uses the algorithm provided by VOCALINK to validate the bank sort code
 and account number.  It is  done by modulus  checking  method as specified in the
 document which is available on their website L<VOCALINK|https://www.vocalink.com/customer-support/modulus-checking>
-It currently supports the L<document|https://www.vocalink.com/media/1786/vocalink-validating-account-numbers-v380-v2.pdf> v3.80 dated 15th Feb'2016.
+It currently supports the L<document|https://www.vocalink.com/media/1911/vocalink-validating-account-numbers-v390.pdf> v3.90 dated 13th June'2016.
 
 Institutions covered by this document are below:
 
